function [WDx, WDy] = Proj2WD(data, angles)
% [WDx, WDy] = Proj2WD(data, angles)
%       Reconstruct the WD of a 2D separable signal as two 2D WD, each 
%       for each coordinate X and Y.
%
%       'data' is a three-index array in which data[i][j][n] is the point
%       (i, j) of the projection n. Note that the i index is the row
%       counter, and therefore associated with the Y coordinate, while
%       the j index is associated with the X coordinate.
%
%       'angles' is a vector that has the same number of elements than the
%       last index of 'data', i e., size(data, 3) == length(angles). It
%       describes the angle in radians for each projection.
%
%       'WDx' and 'WDy' are the WDs associated with the X and Y coordinates
%       correspondingly. 

    % Check that everything looks good
    if (ndims(data) ~= 3)
        error('data must be a 3D array.');
    end;
    if (~isvector(angles))
        error('angles must be a vector.');
    end;
    if (size(angles, 1) == 1)
        angles = angles.';
    end;
    if (size(data, 3) ~= length(angles))
        error('The length of the 3rd index of data must be the same as the lenght of angles.');
    end;

    % Get the projections for each coordinate
    Px = squeeze(sum(data, 1));
    Py = squeeze(sum(data, 2));

    % Reconstruct the Radon transform keeping the same size
    WDx = iradon(Px, angles, size(Px, 1));
    WDy = iradon(Py, angles, size(Py, 1));
